@@ -24,4 +24,7 @@ pub use crate::widgets::sync_rom::SyncROM;
 pub use crate::widgets::synchronizer::{
     BitSynchronizer, SyncReceiver, SyncSender, VectorSynchronizer,
 };
-pub use crate::widgets::mac_fir::MultiplyAccumulateSymmetricFiniteImpulseResponseFilter;
\ No newline at end of file
+pub use crate::widgets::mac_fir::MultiplyAccumulateSymmetricFiniteImpulseResponseFilter;
+pub use crate::widgets::tristate::TristateBuffer;
+pub use crate::widgets::bidirectional_bus::BidirectionalBusSlave;
+pub use crate::widgets::bidirectional_bus::BidirectionalBusMaster;
\ No newline at end of file
